@@ -1,4 +1,4 @@
-flask_setting ='''
+flask_setting = """
 from flask_env import MetaFlaskEnv
 import os
 
@@ -11,9 +11,9 @@ class BaseSettings(metaclass=MetaFlaskEnv):
     SQLALCHEMY_ECHO = True
     SQLALCHEMY_TRACK_MODIFICATIONS = False
 
-'''
+"""
 
-prod_settings = '''
+prod_settings = """
 from settings.settings import BaseSettings
 import os
 
@@ -28,10 +28,10 @@ class ProdSettings(BaseSettings):
     DB_PASSWORD = os.getenv("DB_PASSWORD","")
     DB_USER = os.getenv("DB_USER","postgres")
 
-    SQLALCHEMY_DATABASE_URI = f"postgresql://{DB_USER}:{DB_PASSWORD}@{DB_HOST}:{DB_PORT}/{DB_NAME}"
-'''
+    SQLALCHEMY_DATABASE_URI = f"DB_DRIVER://{DB_USER}:{DB_PASSWORD}@{DB_HOST}:{DB_PORT}/{DB_NAME}"
+"""
 
-dev_settings = '''
+dev_settings = """
 from settings.settings import BaseSettings
 from datetime import timedelta
 import os
@@ -40,8 +40,9 @@ class DevelopSettings(BaseSettings):
     
     DEBUG=True
     ENV="development"
-    SQLALCHEMY_DATABASE_URI = f"postgresql:///streamdb"
+    SQLALCHEMY_DATABASE_URI = "DB_DRIVER:///DB_NAME"
     JWT_SECRET_KEY = os.urandom(32)
     JWT_ACCESS_TOKEN_EXPIRES = timedelta(minutes=3)
 
-'''
\ No newline at end of file
+"""
+
